/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Alexander Bokovoy (alexander.bokovoy@nokia.com)
**
** This file is part of Feed engine.
**
** $FEED_ENGINE_BEGIN_LICENSE$
** This software, including documentation, is protected by copyright controlled by
** Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
** adapting or translating, any or all of this material requires the prior written consent
** of Nokia Corporation. This material also contains confidential information which may
** not be disclosed to others without the prior written consent of Nokia.
** $FEED_ENGINE_END_LICENSE$
**
****************************************************************************/

#ifndef FEEDERROR_H
#define FEEDERROR_H

#include <QtCore/QObject>
#include <QtCore/QMetaType>

//! Errors for feeds
class FeedError : public QObject
{
    Q_OBJECT
    Q_ENUMS(FeedsError)

public:
            FeedError(QObject *parent = 0);
    ~FeedError();

    enum FeedsError {

        NoError = 0,
        NoErrorEnqueued = 1,
        NoErrorAllManualEnclosuresDownloaded = 2,
        NoErrorMaxLimit = 99,

        //! ######## Permanent errors #########
        PermanentError = 100, // Use this value as a starting bound
        PermanentInvalidUrl = 101, // Invalid url
        PermanentHostNotFound  = 102, // invalid hostname
        PermanentFeedNotFound = 103, // content not found
        PermanentProtocolError = 104, // Invalid protocol or unsupported protocol operation
        //! Add any more permanent errors here
        PermanentUnknownError = 199, // end of permanent errors. Use this as an ending bound

        //! ######## Temporary errors #########
        //! Feed Engine internal errors
        TemporaryEngineReformattingFailed = 200,
        TemporaryEngineDownloadCanceled = 201,
        TemporaryEngineEditChannelFailed = 202,
        TemporaryEngineDownloadPaused = 203,
        TemporaryMassStorageModeEnter = 204,
        TemporaryMassStorageModeExit = 205,
        TemporaryUnknownEngineError = 299,

        //! Non-network errors. Mostly related to content
        TemporaryContentError = 300, // Use this as a starting bound for non-network errors
        TemporaryInvalidContent = 301,
        TemporaryImproperPluginInstallation = 302,
        TemporaryParsingFailed = 303,
        TemporaryContentUptoDate = 304,
        //! Add more non-network errors if required here
        TemporaryUnknownError = 399, // Use this as a ending bound for non-network erros

        //! Network errors
        TemporaryNetworkError = 400, // Use this as a starting bound for network errors
        TemporaryServerTimeout = 401,
        TemporaryServerDown = 402,
        TemporaryProxyNotFound = 403, // invalid proxy
        TemporaryProxyTimeout = 404,
        TemporaryProxyDown = 405,
        TemporaryProxyAuthFailed = 406,
        TemporaryAccessDenied = 407,
        TemporaryServerAuthFailed = 408,
        TemporaryNetworkDisconnected = 409,
        TemporaryNetworkConnected = 410, // This is ideally not an error. But including it here to use the same signal to pass the info to reader
        TemporaryNoWifi = 411,

        //! Add any more network related errors here
        TemporaryUnknownNetworkError = 499, // end of temporary errors. Use this as an ending bound
    };
};

typedef FeedError::FeedsError ErrorCode;

Q_DECLARE_METATYPE(ErrorCode)

#endif // FEEDERROR_H
