/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Alexander Bokovoy (alexander.bokovoy@nokia.com)
**
** This file is part of Feed engine.
**
** $FEED_ENGINE_BEGIN_LICENSE$
** This software, including documentation, is protected by copyright controlled by
** Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
** adapting or translating, any or all of this material requires the prior written consent
** of Nokia Corporation. This material also contains confidential information which may
** not be disclosed to others without the prior written consent of Nokia.
** $FEED_ENGINE_END_LICENSE$
**
****************************************************************************/


#ifndef FEEDSETTINGSERVICE_H
#define FEEDSETTINGSERVICE_H

#include "feedserviceshared.h"
#include "feedengineproxy.h"

class FeedSettingServicePrivate;

/*!
  \class FeedSettingService
  \brief The FeedSettingService component provides access to services provided
  by feed engine for changing and reading its settings.
  Feed engine settings can be chaged using this component.
  The typical usage is like following:
  \code
  #include <FeedServices>
  ...
  FeedServices *service = FeedServices::instance();
  QVariantMap settings; // New or modified settings
  settings.insert(key, value);
  service->settings()->setConf(settings);
  ...
  delete service;
  \endcode
  */
class FeedSettingService : public FeedEngineProxy
        , public Feeds::RestrictedCreation
{
Q_OBJECT

public:
    FeedSettingService();
    virtual ~FeedSettingService();

    //! Change to new settings.
    /*!
      Feed engine settings can be modified by passing the new settings in the
      form of QVariantMap. If the new settings is different from old settings and
      if it is within reasonable limit, it will be applied.
      @todo Document the settings that can be changed by client.
      */
    void setConf(const QVariantMap &settings);
    //! Read existing settings.
    /*!
      Returns the existing feed engine settings in form of QVariantMap.
      */
    QVariantMap conf();

private:
    Q_DISABLE_COPY(FeedSettingService);
    Q_DECLARE_PRIVATE(FeedSettingService);
    FeedSettingServicePrivate * const d_ptr;
};

#endif // FEEDSETTINGSERVICE_H
