/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Alexander Bokovoy (alexander.bokovoy@nokia.com)
**
** This file is part of Feed engine.
**
** $FEED_ENGINE_BEGIN_LICENSE$
** This software, including documentation, is protected by copyright controlled by
** Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
** adapting or translating, any or all of this material requires the prior written consent
** of Nokia Corporation. This material also contains confidential information which may
** not be disclosed to others without the prior written consent of Nokia.
** $FEED_ENGINE_END_LICENSE$
**
****************************************************************************/


#ifndef FEEDARGUMENT_H
#define FEEDARGUMENT_H

#include <QGenericArgument>
#include <QDataStream>
#include <QMetaType>
#include <QDebug>

/*!
  * \class Wrapper Class to serilize argument for method
  */
class FeedArgument
{
public:
    //! Constructor
    FeedArgument();

    //! Destructor
    ~FeedArgument();

    //! Returns generic argument for this argument
    QGenericArgument toGenericArgument();

    //! Returns if argument is valid or not
    bool isValid() const;

    QByteArray _typeName;
    QByteArray _argument;
    void* _voidData;
};
Q_DECLARE_METATYPE(FeedArgument)

QDataStream& operator<< ( QDataStream& stream, const FeedArgument& arg );
QDataStream& operator>> ( QDataStream& stream, FeedArgument& arg );

//! helper method to create feedArgument from Data type
template<class T>
static FeedArgument toFeedArgument(T arg)
{
    int type = qMetaTypeId<T>();
    QByteArray data;
    QDataStream readStream (&data, QIODevice::ReadWrite);
    QMetaType::save(readStream, type , static_cast<void*> (&arg) );

    FeedArgument feedArg;
    feedArg._typeName = QMetaType::typeName(type);
    feedArg._argument = data;
    return feedArg;
}

//! helper method to create feedArgument from void pointer and meta type id
static FeedArgument voidToFeedArgument( int type, void* data )
{
    FeedArgument feedArg;
    feedArg._typeName = QMetaType::typeName(type);
    QDataStream readStream (&feedArg._argument, QIODevice::ReadWrite);
    QMetaType::save(readStream, type ,data );
    return feedArg;
}

//! helper method to create data type from bytes
template<class T>
static T bytesToType( QByteArray& byteData )
{
    T data;
    QDataStream readStrem( &byteData,QIODevice::ReadWrite);
    readStrem >> data;
    return data;
}


#endif //FEEDARGUMENT_H
