/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Alexander Bokovoy (alexander.bokovoy@nokia.com)
**
** This file is part of Feed engine.
**
** $FEED_ENGINE_BEGIN_LICENSE$
** This software, including documentation, is protected by copyright controlled by
** Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
** adapting or translating, any or all of this material requires the prior written consent
** of Nokia Corporation. This material also contains confidential information which may
** not be disclosed to others without the prior written consent of Nokia.
** $FEED_ENGINE_END_LICENSE$
**
****************************************************************************/


#ifndef FEEDATOMIC_H
#define FEEDATOMIC_H

#include <QtCore/QAtomicInt>

/*!
    This is a helper for the assignment operators of implicitly
    shared classes. Your assignment operator should look like this:
*/
template <typename T>
inline void feedAtomicAssign(T *&d, T *x)
{
    if (d == x)
        return;
    x->_ref.ref();
    if (!d->_ref.deref())
        delete d;
    d = x;
}

/*!
    This is a helper for the detach method of implicitly shared
    classes. Your private class needs a copy constructor which copies
    the members and sets the refcount to 1. After that, your detach
    function should look like this:
*/
template <typename T>
inline void feedAtomicDetach(T *&d)
{
    if (d->_ref == 1)
        return;
    T *x = d;
    d = new T(*d);
    if (!x->_ref.deref())
        delete x;
}

#endif // FEEDATOMIC_H
