/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Alexander Bokovoy (alexander.bokovoy@nokia.com)
**
** This file is part of Feed engine.
**
** $FEED_ENGINE_BEGIN_LICENSE$
** This software, including documentation, is protected by copyright controlled by
** Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
** adapting or translating, any or all of this material requires the prior written consent
** of Nokia Corporation. This material also contains confidential information which may
** not be disclosed to others without the prior written consent of Nokia.
** $FEED_ENGINE_END_LICENSE$
**
****************************************************************************/


#ifndef FEEDMETHOD_H
#define FEEDMETHOD_H

#include <QGenericArgument>
#include <QList>
#include "feedargument.h"

/*!
  * \class Class that used to seriliaze method and its argument.
  */
class FeedMethod
{
    //! method to seriliaze FeedMethod
    friend QDataStream& operator>> ( QDataStream& stream, FeedMethod& method );
    friend QDataStream& operator<< ( QDataStream& stream, const FeedMethod& method );

public:

    /*! Constructor
      * @param methodName name of method
      * @param args argument of method
      */
    FeedMethod(const QByteArray& methodName, QList<FeedArgument>& args );

    //! Constructor
    FeedMethod();

    /*! Method to add argument  in to method,
      * Only nine argument can be added to method
      * @param arg Argument to be added
      */
    void addArgument( const FeedArgument& arg);

    //! Argument at mentioned at index
    FeedArgument argument(int index );

    //! Return generic arguments for this method's argument
    QList<QGenericArgument> genericArguments();

    //! returns argument count for this method
    int argumentCount();

    //! create FeedMethod instace from byte array
    //static FeedMethod fromByteArray( QByteArray& data );

    //! create bytearray from specified method
    static QByteArray toByteArray( const FeedMethod& method );

    QByteArray _method;
    QByteArray _returnTypeName;

private:

    QList<FeedArgument> _arguments;
};
Q_DECLARE_METATYPE(FeedMethod)

QDataStream& operator<< ( QDataStream& stream, const FeedMethod& arg );
QDataStream& operator>> ( QDataStream& stream, FeedMethod& arg );

//! helper method to create FeedMethod
static FeedMethod toFeedMethod(const QByteArray& method,
                       FeedArgument arg0 = FeedArgument(),
                       FeedArgument arg1 = FeedArgument(),
                       FeedArgument arg2 = FeedArgument(),
                       FeedArgument arg3 = FeedArgument(),
                       FeedArgument arg4 = FeedArgument(),
                       FeedArgument arg5 = FeedArgument(),
                       FeedArgument arg6 = FeedArgument(),
                       FeedArgument arg7 = FeedArgument(),
                       FeedArgument arg8 = FeedArgument(),
                       FeedArgument arg9 = FeedArgument())
{
     FeedMethod feedMethod;
     feedMethod._method = method;
     feedMethod._returnTypeName = QByteArray();
     feedMethod.addArgument( arg0 );
     feedMethod.addArgument( arg1 );
     feedMethod.addArgument( arg2 );
     feedMethod.addArgument( arg3 );
     feedMethod.addArgument( arg4 );
     feedMethod.addArgument( arg5 );
     feedMethod.addArgument( arg6 );
     feedMethod.addArgument( arg7 );
     feedMethod.addArgument( arg8 );
     feedMethod.addArgument( arg9 );

     return feedMethod;
}

//! helper method to create FeedMethod with return argument
template<class T>
static FeedMethod toFeedMethod(const QByteArray& method,
                       FeedArgument arg0 = FeedArgument(),
                       FeedArgument arg1 = FeedArgument(),
                       FeedArgument arg2 = FeedArgument(),
                       FeedArgument arg3 = FeedArgument(),
                       FeedArgument arg4 = FeedArgument(),
                       FeedArgument arg5 = FeedArgument(),
                       FeedArgument arg6 = FeedArgument(),
                       FeedArgument arg7 = FeedArgument(),
                       FeedArgument arg8 = FeedArgument(),
                       FeedArgument arg9 = FeedArgument())
{
     FeedMethod feedMethod = toFeedMethod(method,arg0,arg1,arg2,arg3,arg4,arg5,arg6,arg7,arg8,arg9);
     feedMethod._returnTypeName = QMetaType::typeName(qMetaTypeId<T>());
     return feedMethod;
}

#endif //FEEDMETHOD_H
