/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Alexander Bokovoy (alexander.bokovoy@nokia.com)
**
** This file is part of Feed engine.
**
** $FEED_ENGINE_BEGIN_LICENSE$
** This software, including documentation, is protected by copyright controlled by
** Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
** adapting or translating, any or all of this material requires the prior written consent
** of Nokia Corporation. This material also contains confidential information which may
** not be disclosed to others without the prior written consent of Nokia.
** $FEED_ENGINE_END_LICENSE$
**
****************************************************************************/


#ifndef FEEDCHANNELXMLCONVERTER_H
#define FEEDCHANNELXMLCONVERTER_H


#include "feedabstractxmlconverter.h"
#include "feedchannel.h"
#include <QObject>

/**************************************************************************************************
 Sample channel data

              <channel>
                <title>msg title</title>
                <link>http://foo.com/link.html</link>
                <description>http://foo.com/link.html</description>
                <message>
                    .......
                 </message>
              </channel>

  *************************************************************************************************/

class FeedChannelXmlConverter : public FeedAbstractXmlConverter
{
    Q_OBJECT

public: // methods
    FeedChannelXmlConverter();

    //! Parses a <channel> DOM tree. Handles all nodes under channel and invokes FeedMessageXmlConverter for <message> nodes
    bool parseDomNode(const QDomElement &node);
    //! Returns a FeedChannel object. This function is called by FeedxmlConverter to retrieve the channel info after all the parsing is done
    FeedChannel channel();
    //! Returns a FeedChannel node to which a FeedMessage object can be set as a child.
    //! This is used only for internal purpose when we want to set a message as a child of channel
    FeedNode* feedNode();

private: // data
    //! Channel data structure
    FeedChannel _channel;

private: // methods
    //! Extracts all known channel tags except message tags, i.e. tags which belong to common xml
    void extractKnownChannelNode(const QDomElement &e);
    //! Extracts all messages. This done after all Known channel nodes and namespace nodes are parsed
    void extractMessages(const QDomElement &root);
    //! Extracts the channel icon info
    void extractIcon(const QDomElement &e);
};

#endif // FEEDCHANNELXMLCONVERTER_H
