/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Alexander Bokovoy (alexander.bokovoy@nokia.com)
**
** This file is part of Feed engine.
**
** $FEED_ENGINE_BEGIN_LICENSE$
** This software, including documentation, is protected by copyright controlled by
** Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
** adapting or translating, any or all of this material requires the prior written consent
** of Nokia Corporation. This material also contains confidential information which may
** not be disclosed to others without the prior written consent of Nokia.
** $FEED_ENGINE_END_LICENSE$
**
****************************************************************************/


#ifndef FEEDENCLOSUREXMLCONVERTER_H
#define FEEDENCLOSUREXMLCONVERTER_H

#include "feedabstractxmlconverter.h"
#include "feedenclosure.h"
#include <QObject>

/**************************************************************************************************
 Sample enclosure data

 Sample 1:
              <enclosure url="http://www.foo.com/enclosure.mpg" length=12345/>

 Sample 2:
              <enclosure url="http://www.foo.com/enclosure.mpg" length=12345>
                  <enclosurethumbnail>http://www.foo.com/thumbnail.jpg</enclosurethumbnail>
              </enclosure>
  *************************************************************************************************/

//! Converts Enclosure DOM tree to FeedEnclosure datastructure
class FeedEnclosureXmlConverter : public FeedAbstractXmlConverter
{
    Q_OBJECT

public:
    FeedEnclosureXmlConverter();
    //! Parses a <enclosure> DOM tree. Handles all nodes under <enclosure>
    bool parseDomNode(const QDomElement &node);
    //! Returns FeedEnclosure node. As of now, this will not be used as FeedEnclosure is a leaf node in the tree.
    FeedNode* feedNode();

private:
    //! FeedEnclosure Object
    FeedEnclosure _enclosure;

    //! Extracts all xml attributes of <enclosure> node
    void extractAttributes(const QDomElement &node);
    //! Extracts all child nodes of <enclosure> node
    void extractChildren(const QDomElement &node);
    //! Extracts all properties found from the above methods and sets to the enclosure
    void extractProperties();
};

#endif // FEEDENCLOSUREXMLCONVERTER_H
