/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Alexander Bokovoy (alexander.bokovoy@nokia.com)
**
** This file is part of Feed engine.
**
** $FEED_ENGINE_BEGIN_LICENSE$
** This software, including documentation, is protected by copyright controlled by
** Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
** adapting or translating, any or all of this material requires the prior written consent
** of Nokia Corporation. This material also contains confidential information which may
** not be disclosed to others without the prior written consent of Nokia.
** $FEED_ENGINE_END_LICENSE$
**
****************************************************************************/


#ifndef FEEDMESSAGEXMLCONVERTER_H
#define FEEDMESSAGEXMLCONVERTER_H

#include "feedabstractxmlconverter.h"
#include "feedmessage.h"
#include <QObject>
#include <QStringList>

/**************************************************************************************************
 Sample message data

 Sample 1:
              <message>
                <title>msg title</title>
                <link>http://foo.com/link.html</link>
                <description>http://foo.com/link.html</description>
                <enclosure url="http://www.foo.com/enclosure.mpg" length=12345/>
              </message>

 Sample 2:
              <message>
                <title>msg title</title>
                <link>http://foo.com/link.html</link>
                <description>http://foo.com/link.html</description>
                <enclosuregroup>
                    <enclosure url="http://www.foo.com/enclosure1.mpg" length=12345/>
                    <enclosure url="http://www.foo.com/enclosure2.mpg" length=12345/>
                </enclosuregroup>
              </message>
  *************************************************************************************************/

//! Converts a message DOM tree to FeedMessage datastructure
class FeedMessageXmlConverter : public FeedAbstractXmlConverter
{
    Q_OBJECT

public:
    FeedMessageXmlConverter();
    //! Parses a <message> DOM tree. Handles all nodes under message and invokes FeedEnclosureGroupXmlConverter for <enclosuregroup> nodes
    //! and FeedEnclosureXmlConverter for <enclosure> nodes
    bool parseDomNode(const QDomElement &node);
    //! Returns FeedMessage object
    FeedNode* feedNode();

private:
    //! Keeps track of the group id to be used
    int _currentEnclosureGroupId;
    //! FeedMessage object
    FeedMessage _message;

    //! Original enclosure link obtained from feedburner:origEnclosureLink tag
    QString _origEnclosureLink;

    //! Maintains the namespace priority list for tags like description
    //! Currently only description tag has the priority list maintained
    //! Add more tags if necessary later
    QMap<QString, QStringList> _priorityMap;

    //! Stores the namespace URI from which the current description was taken
    QString _currentDescriptionNamespace;


    //! Extracts all nodes in a message except <enclosuregroup> and <enclosure> nodes
    void extractKnownMessageNode(const QDomElement &node);
    //! Extracts the <enclosuregroup> and <enclosure> nodes
    void extractEnclosureNodes(const QDomElement &messageNode);
    //! Extracts original enclosure link her, Eg: feedburner:origEnclosureLink
    void extractOrigEnclosureNode();
    //! Extracts summary of the description. It will be maximum 100 characters
    void extractSummary(const QDomElement &descriptionNode);
    //! Serializes the description. If there are html tags without CDATA, this will convert it to string format
    QDomElement handleDescriptionContent(const QDomElement &node);

    //! get namespace priority list for all message tags
    void initNamespacePriorityList();
    //! checks if description can be accepted based on the namespace
    bool acceptDescription(const QDomElement &e);
    //! returns priority index of a perticular namespace
    int getDescriptionPriorityIndex(const QString &namespaceUri);
    //! sets the message description from the given node
    void setMessageDescription(const QDomElement &node);

};

#endif // FEEDMESSAGEXMLCONVERTER_H
