/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Alexander Bokovoy (alexander.bokovoy@nokia.com)
**
** This file is part of Feed engine.
**
** $FEED_ENGINE_BEGIN_LICENSE$
** This software, including documentation, is protected by copyright controlled by
** Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
** adapting or translating, any or all of this material requires the prior written consent
** of Nokia Corporation. This material also contains confidential information which may
** not be disclosed to others without the prior written consent of Nokia.
** $FEED_ENGINE_END_LICENSE$
**
****************************************************************************/


#ifndef FEEDNAMESPACEPLUGININTERFACE_H
#define FEEDNAMESPACEPLUGININTERFACE_H

#include <QtPlugin>

class QDomElement;

/*!
  \class FeedNamespacePluginInterface is a plugin interface that can be used to allow support for new namespaces for feeds.
 */
class FeedNamespacePluginInterface
{
 public:
    //! Destructor
    virtual ~FeedNamespacePluginInterface() {}

   /*! Plugin should implement this interface. It should return a list of namespaces this plugin supports
    * \return QStringList list of namespace URIs supported
    */
    virtual QStringList supportedURIList() = 0;

    /*! Plugin should implement this interface. Converts a given node to known node.
      * \param messageNode Node to be parsed
      * \return QDomElement replaced node else returns an Empty node.
      */
    virtual QDomElement convertNode(const QDomElement&) = 0;

};

QT_BEGIN_NAMESPACE
Q_DECLARE_INTERFACE (FeedNamespacePluginInterface, "maemo.org.feednamespaceplugininterface/1.0");
QT_END_NAMESPACE

#endif
