/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Alexander Bokovoy (alexander.bokovoy@nokia.com)
**
** This file is part of Feed engine.
**
** $FEED_ENGINE_BEGIN_LICENSE$
** This software, including documentation, is protected by copyright controlled by
** Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
** adapting or translating, any or all of this material requires the prior written consent
** of Nokia Corporation. This material also contains confidential information which may
** not be disclosed to others without the prior written consent of Nokia.
** $FEED_ENGINE_END_LICENSE$
**
****************************************************************************/


#ifndef FEEDPLUGINAPPLICATION_H
#define FEEDPLUGINAPPLICATION_H

#include <QCoreApplication>

class FeedPluginInterface;
class FeedPluginApplicationPrivate;

/*!
  \class FeedPluginApplication handles communication protocol between plugin and FeedEngine
 */
class FeedPluginApplication : public QCoreApplication
{
    Q_DISABLE_COPY(FeedPluginApplication)

public:
    /*!
      * Constructor
      * @param plugin Valid instance of FeedPluginInterface, used for communication
      * @param argc argument count
      * @param argv arguments
      */
    FeedPluginApplication( FeedPluginInterface* plugin, int argc, char* argv[] );

    //! Destructor
    ~FeedPluginApplication();

private:

    FeedPluginApplicationPrivate* d_ptr;
};

//! macro that implement main function and create application event loop
/// @todo check if class is derived from FeedPluginBase or not by using q_objectcast<FeedPluginInterface>
#define DECLARE_FEED_PLUGIN( PLUGIN_CLASS_NAME ) \
int main( int argc, char* argv[] ) \
{\
 FeedPluginApplication app( new PLUGIN_CLASS_NAME(),argc,argv);\
 return app.exec();\
}

#endif // FEEDPLUGINAPPLICATION_H
