/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Alexander Bokovoy (alexander.bokovoy@nokia.com)
**
** This file is part of Feed engine.
**
** $FEED_ENGINE_BEGIN_LICENSE$
** This software, including documentation, is protected by copyright controlled by
** Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
** adapting or translating, any or all of this material requires the prior written consent
** of Nokia Corporation. This material also contains confidential information which may
** not be disclosed to others without the prior written consent of Nokia.
** $FEED_ENGINE_END_LICENSE$
**
****************************************************************************/


/* * This file is part of libfeedengine *
* Copyright  2009 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
* Contact: Alexander Bokovoy <alexander.bokovoy@nokia.com>
* This software, including documentation, is protected by copyright controlled by
* Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
* adapting or translating, any or all of this material requires the prior written consent
* of Nokia Corporation. This material also contains confidential information which may
* not be disclosed to others without the prior written consent of Nokia.
*/

/*!
 ** feedxmlconverter.h
 **
 */

#ifndef FEEDXMLCONVERTER_H
#define FEEDXMLCONVERTER_H

#include <QtCore/QList>
#include <QUrl>

class FeedXmlConverterPrivate;
class FeedChannel;
class FeedMessage;
class FeedFilenameGenerator;

/*!
  \class FeedXmlConverter accepts a Feed Xml date and creates
   FeedChannel structure.
  The source feed content should be of the following template
  <channel>
    <title></title>
    <link></link>
    <image></image>
    <description></description>

    <message>
        <link>
        <title>
        <description>
	<pubDate>
        <enclosuregroup>
            <enclosure></enclosure>
            <enclosure></enclosure>
            <enclosure></enclosure>
        </enclosuregroup>            
    </message>

    <message>
        <link>
        <title>
        <description>
	<pubDate>
        <enclosure></enclosure>
    </message>

  </channel>
*/

class FeedXmlConverter
{
public: // methods

    //! creates a FeedXmlConverter
    FeedXmlConverter();
    //! destroys the FeedXmlConverter
    ~FeedXmlConverter();

    /*!
      Create a copy of FeedXmlConverter from the \a other
      FeedXmlConverter a = b;
     */
    FeedXmlConverter(const FeedXmlConverter &other);

    /*!
      Copies the contents of \a other to \a this object
     */
    FeedXmlConverter& operator=(const FeedXmlConverter &other);

    /*!
      constructor, create a FeedXmlConverter from the dom \a doc
      FeedXmlConverter a(domDoc);
      FeedXmlConverter a = doc; // fails
     */
    explicit FeedXmlConverter(const QString &feed);


    //! Accepts a feed xml content for further processing. The channel and all the feeds are extracted from this content
    bool setSourceFeed(const QString &sourceFeed);

    //! Returns the channel data structure with all its messages
    FeedChannel channel();

private:
    FeedXmlConverterPrivate *_impl;   /// d-ptr
};

#endif // FEEDXMLCONVERTER_H
